% function mardiademo(alpha)
clear all;
clc;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Computes mardia's coefficients of multivariate skew and kurtosis %
%   Tests the significance using approximate critical values from   %
% Bonett, D.G., Woodward, J. A. Woodward, Randall, R. L. Estimating %
% p-values for Mardias coefficients of multivariate skewness and    %
%    kurtosis.  Computational Statistics, 17 (1), 117-121. 2002.    %
%                                                                   %
%               J. Authur Woodward, Hongjing LU, Nov 03             %
%                          Test data                                %
%                                                                   %
%   Test data in file: test_data_seber.txt from Seber(1984),p74-75  % 
%    bi,4 = 4.476; b24=22.957                                       % 
%                                                                   %
%                                                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if nargin<1
    alpha=0.05;
end;

[filename,vn]=glmtdfread;
yx=cellstr(vn');
nameexten='_________';
for i=1:size(yx,1)
    assignin('base',strcat(yx{i},nameexten),eval(yx{i}));
    strnamedisp{i}=yx{i};
    yxtemp{i}=strcat(yx{i},nameexten);
end;
for i=1:size(yx,1)
    eval(sprintf('clear %s',yx{i}));
end;
clear yx;
strname=yxtemp;
clear yxtemp;
valnum =size(strname,2);
datanum = size(eval(strname{1}),1);
i=0;
boxpos = [10 300];
boxsize = [200 200];
% set up figure configuration
set(0,'Units','pixels') 
while 1
    i=i+1; 
    [sbox,vbox]=listdialogbox(strnamedisp,boxpos, boxsize,'Variable List', 'Select the dependent variable:','End','OK','Transform','multiple');
    if vbox==0
        break;
    else        
        if vbox==2  %% ask for the function
            fprintf('The selected variable is: %s\n',char(strnamedisp(sbox)));
            [s1,v1,xval]=funclist(char(strname(sbox)),[10 10], [200 200],'Function Selection', 'Select the function:');
            if s1<12
                if s1==2  %lag operation
                    % ask questions about how many lags
                    if exist('y')
                        clear y;
                    end;
                    y(:,i)=eval((xval));
                    namey{i,1}=strrep(char(xval),nameexten,'');

                    yinput = y;
					prompt  = {'Enter lag number:'};
					title   = 'Input for Lag Function';
					lines= 1;
					def     = {'1'};
					lagcell  = inputdlg(prompt,title,lines,def);
					lag=str2num(lagcell{1,1});
                    % lag operation
					varnum = size(strname,2);
					for ii=1:lag
                        % form new lag variable
                        for j=1:1%size(namey,1)
                            varnum=varnum+1;
                            strnamedisp{varnum}=sprintf('%slag%d',strrep(char(xval),nameexten,''),ii);
                            strname{varnum}=strcat(strnamedisp{varnum},nameexten);
                            assignin('base',strname{varnum},yinput(1:size(yinput,1)-ii,j));
                        end;
					%     % trimming
                        for jj=1:varnum-1
                            temp = eval(char(strname(jj)));
                            assignin('base',strname{1,jj},temp(1+1:size(temp,1)));
                        end;
					end;
                    clear y;
                    y(:,i)=eval((xval));

                else
                    y(:,i)=eval((xval));
                    namey{i,1}=strrep(char(xval),nameexten,'');
                end;
            else  % multiple var transfer
                [s2,v2]=listdialogbox(strnamedisp,[boxpos(1)+100 boxpos(2)], boxsize,'Variable List', 'Select the variable for the function:','End','OK','Transform');
                if v2==2  %% ask for the function
                        [s3,v3,xval3]=funclist(char(strname(s2)),[10+100 10], [200 200],'Function Selection', 'Select the function:');
                elseif v2==1  %% no need for the function
                        xval3 = char(strname(s2));
                end;
                if s1==14
                    y(:,i)=eval(sprintf('%s+%s',xval,xval3));
                    namey{i,1}=strrep(sprintf('%s+%s',xval,xval3),nameexten,'');
                elseif s1==15
                    y(:,i)=eval(sprintf('%s-%s',xval,xval3));
                    namey{i,1}=strrep(sprintf('%s-%s',xval,xval3),nameexten,'');
                elseif s1==16
                    y(:,i)=eval(sprintf('%s.*%s',xval,xval3));
                    namey{i,1}=strrep(sprintf('%s.*%s',xval,xval3),nameexten,'');
                elseif s1==17
                    y(:,i)=eval(sprintf('%s./%s',xval,xval3));
                    namey{i,1}=strrep(sprintf('%s./%s',xval,xval3),nameexten,'');
                end;
            end
        elseif vbox==1  %% No need for the function
            if size(sbox,2)>1
                for ij=1:size(sbox,2)
                    y(:,i)=eval(char(strname(sbox(ij))));
                    namey{i,1}=strrep(char(strnamedisp(sbox(ij))),nameexten,'');      
                    i=i+1;
                end;
            else
                y(:,i)=eval(char(strname(sbox)));
                namey{i,1}=strrep(char(strnamedisp(sbox)),nameexten,'');
            end;
            
        end;

        % display the y matrix
        fprintf('Y = [ ');
            for ij=1:size(namey,1)
                fprintf('%s  ',namey{ij,1});
            end;
        fprintf(']\n');
	end;
end;
x = y;


% x = transpose(reshape(transpose(ebar),p,s));
% d=p;n=s;
d=size(x,2);p=d;
n=size(x,1);s=n;
skewtable=xlsread('skewcv1.xls',sprintf('Sheet%4.2f',alpha));
kurttable=xlsread('kurtcv1.xls',sprintf('Sheet%4.2f',alpha));
if n>size(skewtable,1) | n>size(kurttable,1)
    fprintf('Warning: Sample size exceeds limitation of n=98 \n ');
end
if p<2
    error('Require two or more dependent variables ');
end;

m=mean(x);
mm=kron(ones(n,1),m);
ss=cov(x)*(n-1)/n;
w=inv(ss);
c2=0;a3=0;a5=0;
    while c2<n;
        c2=c2+1;
        a1=(x(c2,:)-m)*w;
        a2=sum(((a1*(x-mm)').^3)');
        a3=a3+a2;
        a4=sum(((a1*(x(c2,:)-m)').^2)');
        a5=a5+a4;
    end;
b1=a3/(n^2);b2=a5/n;

if n<size(skewtable,1) & n<size(kurttable,1)
	skewcritval = skewtable(n-2,p);
	kutcritval1 = kurttable(n-2,(p-1)*2);
	kutcritval2 = kurttable(n-2,(p-1)*2+1);
else   %%&&&&&&&&&&&&&&&&&&&&Art: you need to add the estimation part here.
    skewcritval = -111111;
	kutcritval1 = -111111;
	kutcritval2 = -111111;
end;

fprintf('\n===================================================\n');
fprintf('n = %4d and p = %4d \n',n,p)
fprintf('Mardia multivariate skew = %7.2f;        critical value = %7.2f \n',b1,skewcritval);
if b1>skewcritval
    fprintf('   Reject H0: Skewness is non normal');
    dec1=1;
else
    fprintf('   Accept H0: Skewness is normal');
    dec1=0;
end;
fprintf('\n');
fprintf('Mardia multivariate kurtosis = %5.4f;    critical value = [%7.2f, %7.2f]\n',b2,kutcritval1,kutcritval2);
if b2<=kutcritval2 & b2>=kutcritval1
    dec2=0;
    fprintf('   Accept H0: Kurtosis is normal');
else
    dec2=1;
    fprintf('   Reject H0: Kurtosis is non normal');
end;
fprintf('\n===================================================\n');
